@@ -58,7 +58,19 @@ mkdir -p $datadir
 chmod go-rx $datadir
 chown $user: $datadir
 
-$mysqld --initialize-insecure
+mysql_install_db --no-defaults --user=$user --datadir=$datadir --rpm --force
+
+tmpf=$(mktemp)
+cat > "$tmpf" <<EOF
+USE mysql;
+UPDATE user SET password=PASSWORD('') WHERE user='root';
+UPDATE user SET plugin='' WHERE user='root';
+FLUSH PRIVILEGES;
+EOF
+
+$mysqld --bootstrap --skip-grant-tables < "$tmpf"
+
+unlink "$tmpf"
 
 # Start the daemon
 $mysqld &
